Welcome to ClientVPS Mirrors

Help for package GroupSeq
Title: Group Sequential Design Probabilities - With Graphical User Interface
Version: 1.4.3
Description: Computes probabilities related to group sequential designs for normally distributed test statistics. Enables to derive critical boundaries, power, drift, and confidence intervals of such designs. Supports the alpha spending approach by Lan-DeMets (1994) <doi:10.1002/sim.4780131308>.
Imports: tcltk, tcltk2, mvtnorm
Suggests: knitr, tinytest, rmarkdown, ggplot2, gridExtra
VignetteBuilder: knitr
License: GPL-3
URL: https://rpahl.github.io/GroupSeq/
BugReports: https://github.com/rpahl/GroupSeq/issues
NeedsCompilation: no
Author: Roman Pahl [aut, cre]
Maintainer: Roman Pahl <roman.pahl@gmail.com>
Repository: CRAN
RoxygenNote: 7.2.1
Encoding: UTF-8
Packaged: 2024-02-03 13:09:23 UTC; Roman
Date/Publication: 2024-02-03 16:30:02 UTC

Start GroupSeq

Description

Starts the graphical user interface.

Usage

start_gui()

Value

No return value, called for side effects.

Examples

start_gui()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.